==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebColumnVisibilityChangingEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebColumnVisibilityChangingEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnVisibilityChangingEventArgsDescription, _super);
    function WebColumnVisibilityChangingEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.f = null;
        return _this;
    }
    WebColumnVisibilityChangingEventArgsDescription.prototype.get_type = function () {
        return "WebColumnVisibilityChangingEventArgs";
    };
    Object.defineProperty(WebColumnVisibilityChangingEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebColumnVisibilityChangingEventArgsDescription.prototype, "detail", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Detail");
        },
        enumerable: true,
        configurable: true
    });
    WebColumnVisibilityChangingEventArgsDescription.$t = markType(WebColumnVisibilityChangingEventArgsDescription, 'WebColumnVisibilityChangingEventArgsDescription', Description.$);
    WebColumnVisibilityChangingEventArgsDescription.__marshalByValue = true;
    WebColumnVisibilityChangingEventArgsDescription.__marshalByValueAlias = "ColumnVisibilityChangingEventArgs";
    return WebColumnVisibilityChangingEventArgsDescription;
}(Description));
export { WebColumnVisibilityChangingEventArgsDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebColumnVisibilityChangingEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebColumnVisibilityChangingEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnVisibilityChangingEventArgsDescription, _super);
    function WebColumnVisibilityChangingEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.h = null;
        return _this;
    }
    WebColumnVisibilityChangingEventArgsDescription.prototype.get_type = function () {
        return "WebColumnVisibilityChangingEventArgs";
    };
    Object.defineProperty(WebColumnVisibilityChangingEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebColumnVisibilityChangingEventArgsDescription.prototype, "detail", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("Detail");
        },
        enumerable: false,
        configurable: true
    });
    WebColumnVisibilityChangingEventArgsDescription.$t = markType(WebColumnVisibilityChangingEventArgsDescription, 'WebColumnVisibilityChangingEventArgsDescription', Description.$);
    WebColumnVisibilityChangingEventArgsDescription.__marshalByValue = true;
    WebColumnVisibilityChangingEventArgsDescription.__marshalByValueAlias = "ColumnVisibilityChangingEventArgs";
    return WebColumnVisibilityChangingEventArgsDescription;
}(Description));
export { WebColumnVisibilityChangingEventArgsDescription };
